Integrate Jinja2 into Tornado Framework
======================================

This tool make you have the ability that using jiaja2 Template Engine with Tornado Web Framework.
It will instead of Tornado Templates.

HomePage: https://github.com/mr-ping/tornado_jinja2
